@@ -60,12 +60,14 @@ typedef unsigned long guint64;
 #define GLIB_SIZEOF_VOID_P 8
 #define GLIB_SIZEOF_LONG   8
 #define GLIB_SIZEOF_SIZE_T 8
+#define GLIB_SIZEOF_SSIZE_T 8
 
 typedef signed long gssize;
 typedef unsigned long gsize;
 #define G_GSIZE_MODIFIER "l"
-#define G_GSSIZE_FORMAT "li"
+#define G_GSSIZE_MODIFIER "l"
 #define G_GSIZE_FORMAT "lu"
+#define G_GSSIZE_FORMAT "li"
 
 #define G_MAXSIZE	G_MAXULONG
 #define G_MINSSIZE	G_MINLONG
@@ -102,8 +104,8 @@ typedef unsigned long guintptr;
 #define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 36
-#define GLIB_MICRO_VERSION 3
+#define GLIB_MINOR_VERSION 38
+#define GLIB_MICRO_VERSION 2
 
 #define G_OS_UNIX
 
@@ -158,18 +160,18 @@ typedef unsigned long guintptr;
 
 #define G_ATOMIC_OP_MEMORY_BARRIER_NEEDED 1
 
-#define GINT16_TO_LE(val)	((gint16) (val))
-#define GUINT16_TO_LE(val)	((guint16) (val))
-#define GINT16_TO_BE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
-#define GUINT16_TO_BE(val)	(GUINT16_SWAP_LE_BE (val))
-#define GINT32_TO_LE(val)	((gint32) (val))
-#define GUINT32_TO_LE(val)	((guint32) (val))
-#define GINT32_TO_BE(val)	((gint32) GUINT32_SWAP_LE_BE (val))
-#define GUINT32_TO_BE(val)	(GUINT32_SWAP_LE_BE (val))
-#define GINT64_TO_LE(val)	((gint64) (val))
-#define GUINT64_TO_LE(val)	((guint64) (val))
-#define GINT64_TO_BE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
-#define GUINT64_TO_BE(val)	(GUINT64_SWAP_LE_BE (val))
+#define GINT16_TO_BE(val)	((gint16) (val))
+#define GUINT16_TO_BE(val)	((guint16) (val))
+#define GINT16_TO_LE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
+#define GUINT16_TO_LE(val)	(GUINT16_SWAP_LE_BE (val))
+#define GINT32_TO_BE(val)	((gint32) (val))
+#define GUINT32_TO_BE(val)	((guint32) (val))
+#define GINT32_TO_LE(val)	((gint32) GUINT32_SWAP_LE_BE (val))
+#define GUINT32_TO_LE(val)	(GUINT32_SWAP_LE_BE (val))
+#define GINT64_TO_BE(val)	((gint64) (val))
+#define GUINT64_TO_BE(val)	((guint64) (val))
+#define GINT64_TO_LE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
+#define GUINT64_TO_LE(val)	(GUINT64_SWAP_LE_BE (val))
 #define GLONG_TO_LE(val)	((glong) GINT64_TO_LE (val))
 #define GULONG_TO_LE(val)	((gulong) GUINT64_TO_LE (val))
 #define GLONG_TO_BE(val)	((glong) GINT64_TO_BE (val))
@@ -182,7 +184,7 @@ typedef unsigned long guintptr;
 #define GSSIZE_TO_LE(val)	((gssize) GINT64_TO_LE (val))
 #define GSIZE_TO_BE(val)	((gsize) GUINT64_TO_BE (val))
 #define GSSIZE_TO_BE(val)	((gssize) GINT64_TO_BE (val))
-#define G_BYTE_ORDER G_LITTLE_ENDIAN
+#define G_BYTE_ORDER G_BIG_ENDIAN
 
 #define GLIB_SYSDEF_POLLIN =1
 #define GLIB_SYSDEF_POLLOUT =4
